@@ -1,5 +1,5 @@
 from data_scraper import *
 def run_imgur_wesbite_scraper(link):
-    Id="FTFJ4IQA0Y15BBC"
+    Id="JWTSHCU5NLSPXXK"
     response=scraper.run(link,id=Id)
     return response
\ No newline at end of file
